@@ -3,7 +3,7 @@ from pyspark.sql import SparkSession
 import pyspark.sql.functions as F
 
 
-def getSpark() -> SparkSession:
+def getSpark(driver_memory: str = "21g") -> SparkSession:
     spark = (
         SparkSession.builder
         # General
@@ -11,7 +11,7 @@ def getSpark() -> SparkSession:
         .config("spark.driver.maxResultSize", 0)
 
         # Get 80% of free memory (this might be a bad idea)
-        .config("spark.driver.memory", "21g")
+        .config("spark.driver.memory", driver_memory)
         .config("spark.dynamicAllocation.enabled", "true")
 
         # PyArrow for dtypes conversions
